fakes

package
v0.0.0-...-addb051 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 20, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Overview

Package fakes contains fake implementations for testing purposes.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type PushRemoteRef

type PushRemoteRef struct {
	GetRemoteKeyStub func() string
	// contains filtered or unexported fields
}

PushRemoteRef is a fake implementation of the PushRemoteRef interface for testing.

func (*PushRemoteRef) GetProperty

func (fake *PushRemoteRef) GetProperty() string

GetProperty returns the property value as a string.

func (*PushRemoteRef) GetRemoteKey

func (fake *PushRemoteRef) GetRemoteKey() string

GetRemoteKey returns a string representing the remote key.

func (*PushRemoteRef) GetRemoteKeyCallCount

func (fake *PushRemoteRef) GetRemoteKeyCallCount() int

GetRemoteKeyCallCount returns the number of times GetRemoteKey has been called.

func (*PushRemoteRef) GetRemoteKeyCalls

func (fake *PushRemoteRef) GetRemoteKeyCalls(stub func() string)

GetRemoteKeyCalls sets a custom stub function for the GetRemoteKey method.

func (*PushRemoteRef) GetRemoteKeyReturns

func (fake *PushRemoteRef) GetRemoteKeyReturns(result1 string)

GetRemoteKeyReturns sets return values that will be returned by GetRemoteKey.

func (*PushRemoteRef) GetRemoteKeyReturnsOnCall

func (fake *PushRemoteRef) GetRemoteKeyReturnsOnCall(i int, result1 string)

GetRemoteKeyReturnsOnCall sets return values for specific calls to GetRemoteKey.

func (*PushRemoteRef) Invocations

func (fake *PushRemoteRef) Invocations() map[string][][]any

Invocations returns a map recording the calls to methods on this fake.

Jump to