Documentation
¶
Overview ¶
Package v1 contains meta types for external-secrets APIs +kubebuilder:object:generate=true
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type SecretKeySelector ¶
type SecretKeySelector struct {
// The name of the Secret resource being referred to.
// +kubebuilder:validation:MinLength:=1
// +kubebuilder:validation:MaxLength:=253
// +kubebuilder:validation:Pattern:=^[a-z0-9]([-a-z0-9]*[a-z0-9])?(\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*$
Name string `json:"name,omitempty"`
// The namespace of the Secret resource being referred to.
// Ignored if referent is not cluster-scoped, otherwise defaults to the namespace of the referent.
// +optional
// +kubebuilder:validation:MinLength:=1
// +kubebuilder:validation:MaxLength:=63
// +kubebuilder:validation:Pattern:=^[a-z0-9]([-a-z0-9]*[a-z0-9])?$
Namespace *string `json:"namespace,omitempty"`
// A key in the referenced Secret.
// Some instances of this field may be defaulted, in others it may be required.
// +optional
// +kubebuilder:validation:MinLength:=1
// +kubebuilder:validation:MaxLength:=253
// +kubebuilder:validation:Pattern:=^[-._a-zA-Z0-9]+$
Key string `json:"key,omitempty"`
}
SecretKeySelector is a reference to a specific 'key' within a Secret resource. In some instances, `key` is a required field.
func (*SecretKeySelector) DeepCopy ¶
func (in *SecretKeySelector) DeepCopy() *SecretKeySelector
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SecretKeySelector.
func (*SecretKeySelector) DeepCopyInto ¶
func (in *SecretKeySelector) DeepCopyInto(out *SecretKeySelector)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ServiceAccountSelector ¶
type ServiceAccountSelector struct {
// The name of the ServiceAccount resource being referred to.
// +kubebuilder:validation:MinLength:=1
// +kubebuilder:validation:MaxLength:=253
// +kubebuilder:validation:Pattern:=^[a-z0-9]([-a-z0-9]*[a-z0-9])?(\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*$
Name string `json:"name"`
// Namespace of the resource being referred to.
// Ignored if referent is not cluster-scoped, otherwise defaults to the namespace of the referent.
// +optional
// +kubebuilder:validation:MinLength:=1
// +kubebuilder:validation:MaxLength:=63
// +kubebuilder:validation:Pattern:=^[a-z0-9]([-a-z0-9]*[a-z0-9])?$
Namespace *string `json:"namespace,omitempty"`
// Audience specifies the `aud` claim for the service account token
// If the service account uses a well-known annotation for e.g. IRSA or GCP Workload Identity
// then this audiences will be appended to the list
// +optional
Audiences []string `json:"audiences,omitempty"`
}
ServiceAccountSelector is a reference to a ServiceAccount resource.
func (*ServiceAccountSelector) DeepCopy ¶
func (in *ServiceAccountSelector) DeepCopy() *ServiceAccountSelector
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ServiceAccountSelector.
func (*ServiceAccountSelector) DeepCopyInto ¶
func (in *ServiceAccountSelector) DeepCopyInto(out *ServiceAccountSelector)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.