gcr

package module
v0.0.0-...-a56de81 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 22, 2026 License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Overview

Package gcr provides functionality for generating authentication tokens for Google Container Registry.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Kind

func Kind() string

Kind returns the generator kind.

func NewGenerator

func NewGenerator() genv1alpha1.Generator

NewGenerator creates a new Generator instance.

Types

type Generator

type Generator struct{}

Generator implements GCR token generation functionality.

func (*Generator) Cleanup

Cleanup performs any necessary cleanup after token generation.

func (*Generator) Generate

func (g *Generator) Generate(ctx context.Context, jsonSpec *apiextensions.JSON, kube client.Client, namespace string) (map[string][]byte, genv1alpha1.GeneratorProviderState, error)

Generate creates an authentication token for Google Container Registry. It retrieves the token using the GCP credentials and returns it in the expected format.

Jump to