Documentation
¶
Overview ¶
Package gcr provides functionality for generating authentication tokens for Google Container Registry.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewGenerator ¶
func NewGenerator() genv1alpha1.Generator
NewGenerator creates a new Generator instance.
Types ¶
type Generator ¶
type Generator struct{}
Generator implements GCR token generation functionality.
func (*Generator) Cleanup ¶
func (g *Generator) Cleanup(_ context.Context, _ *apiextensions.JSON, _ genv1alpha1.GeneratorProviderState, _ client.Client, _ string) error
Cleanup performs any necessary cleanup after token generation.
func (*Generator) Generate ¶
func (g *Generator) Generate(ctx context.Context, jsonSpec *apiextensions.JSON, kube client.Client, namespace string) (map[string][]byte, genv1alpha1.GeneratorProviderState, error)
Generate creates an authentication token for Google Container Registry. It retrieves the token using the GCP credentials and returns it in the expected format.
Click to show internal directories.
Click to hide internal directories.